@@ -486,10 +486,10 @@ register char **ccp;
 				n=3;
 				ret = FPI;
 			} else if(c3=='s') {
-				n=3;
+				n= (c4 == 'r' ? 4 : 3);
 				ret = FPS;
 			} else if(c3=='c') {
-				n=3;
+				n= (c4 == 'r' ? 4 : 3);
 				ret = FPC;
 			}
 		}
@@ -2222,6 +2222,7 @@ char *str;
 	char	*toP;
 	int	m,n;
 	char	*to_beg_P;
+	int	shorts_this_frag;
 
 	bzero((char *)(&the_ins),sizeof(the_ins));	/* JF for paranoia sake */
 	m68_ip(str);
@@ -2284,14 +2285,18 @@ char *str;
 		else wid=2*(the_ins.numo-the_ins.fragb[n-1].fragoff);
 		toP=frag_more(wid);
 		to_beg_P=toP;
+		shorts_this_frag=0;
 		for(m=wid/2;m;--m) {
 			md_number_to_chars(toP,(long)(*fromP),2);
 			toP+=2;
 			fromP++;
+			shorts_this_frag++;
 		}
 		for(m=0;m<the_ins.nrel;m++) {
-			if((the_ins.reloc[m].n)/2>the_ins.fragb[n].fragoff)
+			if((the_ins.reloc[m].n)>= 2*shorts_this_frag /* 2*the_ins.fragb[n].fragoff */) {
+				the_ins.reloc[m].n-= 2*shorts_this_frag /* 2*the_ins.fragb[n].fragoff */;
 				break;
+			}
 			wid=the_ins.reloc[m].wid;
 			if(wid==0)
 				continue;
@@ -2311,14 +2316,33 @@ char *str;
  the_ins.fragb[n].fadd,the_ins.fragb[n].foff,to_beg_P);
 	}
 	n=(the_ins.numo-the_ins.fragb[n-1].fragoff);
+	shorts_this_frag=0;
 	if(n) {
 		toP=frag_more(n*sizeof(short));
 		while(n--) {
 			md_number_to_chars(toP,(long)(*fromP),2);
 			toP+=2;
 			fromP++;
+			shorts_this_frag++;
 		}
 	}
+	for(m=0;m<the_ins.nrel;m++) {
+		int wid;
+
+		wid=the_ins.reloc[m].wid;
+		if(wid==0)
+			continue;
+		the_ins.reloc[m].wid=0;
+		wid = (wid=='b') ? 1 : (wid=='w') ? 2 : (wid=='l') ? 4 : 4000;
+
+		fix_new(frag_now,
+		    (the_ins.reloc[m].n + toP-frag_now->fr_literal)-/* the_ins.numo */ shorts_this_frag*2,
+		    wid,
+		    the_ins.reloc[m].add,
+		    the_ins.reloc[m].sub,
+		    the_ins.reloc[m].off,
+		    the_ins.reloc[m].pcrel);
+	}
 }
 
 /* This function is called once, at assembler startup time.  This should
@@ -2622,6 +2646,30 @@ register fragS *fragP;
 	return fragP->fr_var + fragP->fr_fix - old_fix;
 }
 
+/* the bit-field entries in the relocation_info struct plays hell 
+   with the byte-order problems of cross-assembly.  So as a hack,
+   I added this mach. dependent ri twiddler.  Ugly, but it gets
+   you there. -KWK */
+/* on m68k: first 4 bytes are normal unsigned long, next three bytes
+are symbolnum, most sig. byte first.  Last byte is broken up with
+bit 7 as pcrel, bits 6 & 5 as length, bit 4 as pcrel, and the lower
+nibble as nuthin. (on Sun 3 at least) */
+void md_ri_to_chars(ri_p, ri)
+     struct relocation_info *ri_p, ri;
+{
+  unsigned char the_bytes[8];
+  
+  /* this is easy */
+  md_number_to_chars(the_bytes, ri.r_address, sizeof(ri.r_address));
+  /* now the fun stuff */
+  the_bytes[4] = (ri.r_symbolnum >> 16) & 0x0ff;
+  the_bytes[5] = (ri.r_symbolnum >> 8) & 0x0ff;
+  the_bytes[6] = ri.r_symbolnum & 0x0ff;
+  the_bytes[7] = (((ri.r_pcrel << 7)  & 0x80) | ((ri.r_length << 5) & 0x60) | 
+    ((ri.r_extern << 4)  & 0x10)); 
+  /* now put it back where you found it */
+  bcopy (the_bytes, (char *)ri_p, sizeof(struct relocation_info));
+}
 
 /* Different values of OK tell what its OK to return.  Things that aren't OK are an error (what a shock, no?)
 
