@@ -127,6 +127,9 @@ static char *	bignum_high;	/* Highest char of bignum. */
 static char *old_buffer = 0;	/* JF a hack */
 static char *old_input;
 static char *old_limit;
+
+static void grow_bignum ();
+static int next_char_of_string ();
 
 void
 read_begin()
@@ -1402,8 +1405,6 @@ big_cons(nbytes)		/* worker to do .quad etc statements */
     }
   while (c == ',')
     {
-      void grow_bignum();
-
       ++ input_line_pointer;
       SKIP_WHITESPACE();
       c = * input_line_pointer;
