@@ -1382,6 +1382,32 @@ md_convert_frag (fragP)
     }
   fragP -> fr_fix += extension;
 }
+
+/* the bit-field entries in the relocation_info struct plays hell 
+   with the byte-order problems of cross-assembly.  So as a hack,
+   I added this mach. dependent ri twiddler.  Ugly, but it gets
+   you there. -KWK */
+/* on vax: first 4 bytes are normal unsigned long, next three bytes
+   are symbolnum, least sig. byte first.  Last byte is broken up with
+   the upper nibble as nuthin, bit 3 as extern, bits 2 & 1 as length, and
+   bit 0 as pcrel. */
+void md_ri_to_chars(ri_p, ri)
+     struct relocation_info *ri_p, ri;
+{
+  unsigned char the_bytes[8];
+  
+  /* this is easy */
+  md_number_to_chars(the_bytes, ri.r_address, sizeof(ri.r_address));
+  /* now the fun stuff */
+  the_bytes[6] = (ri.r_symbolnum >> 16) & 0x0ff;
+  the_bytes[5] = (ri.r_symbolnum >> 8) & 0x0ff;
+  the_bytes[4] = ri.r_symbolnum & 0x0ff;
+  the_bytes[7] = (((ri.r_extern << 3)  & 0x08) | ((ri.r_length << 1) & 0x06) | 
+    ((ri.r_pcrel << 0)  & 0x01)) & 0x0F; 
+  /* now put it back where you found it */
+  bcopy (the_bytes, (char *)ri_p, sizeof(struct relocation_info));
+}
+
 
 
 	/* JF this used to be a separate file */
@@ -2394,8 +2420,13 @@ vip_op (optext, vopP)
 	       * parenthesised expressions? BECAUSE I AM LAZY! That is why.
 	       * Abuse luser if we didn't spy a register name.
 	       */
-	      if ( reg < 0 )
-		  err = "unknown register in ()";
+	      if ( reg < 0 ) {
+	          /* JF allow parenthasized expressions.  I hope this works */
+	          paren = FALSE;
+		  while(*q!=')')
+		  	q++;
+		  /* err = "unknown register in ()"; */
+	      }
 	      else
 		  q--;		/* point just before '(' of "(...)" */
 	      /*
