@@ -136,6 +136,15 @@ write_object_file()
   extern long omagic;		/* JF magic # to write out.  Is different for
 				   Suns and Vaxen and other boxes */
 
+#ifdef	VMS
+  /*
+   *	Under VMS we try to be compatible with VAX-11 "C".  Thus, we
+   *	call a routine to check for the definition of the procedure
+   *	"_main", and if so -- fix it up so that it can be program
+   *	entry point.
+   */
+  VMS_Check_For_Main();
+#endif	VMS
   /*
    * After every sub-segment, we fake an ".align ...". This conforms to BSD4.2
    * brane-damage. We then fake ".fill 0" because that is the kind of frag
@@ -145,6 +154,16 @@ write_object_file()
 #define SUB_SEGMENT_ALIGN (2)
   for ( frchainP=frchain_root; frchainP; frchainP=frchainP->frch_next )
     {
+#ifdef VMS
+	/*
+	 *	Under VAX/VMS, the linker (and PSECT specifications)
+	 *	take care of correctly aligning the segments.
+	 *	Doing the alignment here (on initialized data) can
+	 *	mess up the calculation of global data PSECT sizes.
+	 */
+	if(frchainP->frch_seg == SEG_DATA)
+		continue;
+#endif
       subseg_new (frchainP -> frch_seg, frchainP -> frch_subseg);
       frag_align (SUB_SEGMENT_ALIGN, 0);
 				/* frag_align will have left a new frag. */
@@ -308,21 +327,27 @@ write_object_file()
 	   used instead of 128. */
 		/* JF the \001 bit is to make sure that local labels
 		   ( 1: - 9: don't make it into the symtable either */
+#ifndef VMS
 	if ( !name || (symbolP->sy_nlist.n_type&N_STAB)
 	    || (name[0]!='\001' && (flagseen ['L'] || name [0] != 'L' )))
+#endif	/* not VMS */
 	  {
 	    symbolP -> sy_number = symbol_number ++;
+#ifndef VMS
 	    if (name)
 	      {			/* Ordinary case. */
 		symbolP -> sy_name_offset = string_byte_count;
 		string_byte_count += strlen (symbolP  -> sy_name) + 1;
 	      }
 	    else			/* .Stabd case. */
+#endif	/* not VMS */
 		symbolP -> sy_name_offset = 0;
 	    symbolPP = & (symbolP -> sy_next);
 	  }
+#ifndef VMS
 	else
 	    * symbolPP = symbolP -> sy_next;
+#endif	/* not VMS */
       }				/* for each symbol */
 
     syms_siz = sizeof( struct nlist) * symbol_number;
@@ -370,6 +395,7 @@ write_object_file()
 	}			/* switch (fr_type) */
     }				/* for each frag. */
 
+#ifndef VMS
   /*
    * Scan every FixS performing fixups. We had to wait until now to do
    * this because md_convert_frag() may have made some fixSs.
@@ -459,6 +485,9 @@ write_object_file()
    * Emit strings.
    * Find strings by crawling along symbol table chain.
    */
+/* Gotta do md_ byte-ordering stuff for string_byte_count first - KWK */
+  md_number_to_chars((char *)&string_byte_count, string_byte_count, sizeof(string_byte_count));
+
   append (& next_object_file_charP, (char *)&string_byte_count, (unsigned long)sizeof(string_byte_count));
   for (   symbolP = symbol_rootP;   symbolP;   symbolP = symbolP -> sy_next   )
     {
@@ -480,6 +509,12 @@ write_object_file()
     }
 
   output_file_close (out_file_name);
+#else	/* VMS */
+  /*
+   *	Now do the VMS-dependent part of writing the object file
+   */
+  VMS_write_object_file(text_siz, data_siz, text_frag_root, data_frag_root);
+#endif	/* VMS */
 }				/* write_object_file() */
 
 /*
@@ -494,7 +529,10 @@ write_object_file()
  * within the segment. Since segments live in different file addresses,
  * these frag addresses may not be the same as final object-file addresses.
  */
-static void
+#ifndef VMS
+static
+#endif	/* not VMS */
+void
 relax_segment (segment_frag_root, segment_type)
      struct frag *	segment_frag_root;
      segT		segment_type; /* N_DATA or N_TEXT */
@@ -884,6 +922,17 @@ emit_relocations (fixP, segment_address_in_file)
 	      ri . r_extern	= 0;
 	      ri . r_symbolnum	= symbolP -> sy_type & N_TYPE;
 	    }
+
+	  /* 
+	    The 68k machines assign bit-fields from higher bits to 
+	    lower bits ("left-to-right") within the int.  VAXen assign 
+	    bit-fields from lower bits to higher bits ("right-to-left").
+	    Both handle multi-byte numbers in their usual fashion
+	    (Big-endian and little-endian stuff).
+	    Thus we need a machine dependent routine to make
+	    sure the structure is written out correctly.  FUN!
+	   */
+	  md_ri_to_chars((char *) &ri, ri); 
 	  append (&next_object_file_charP, (char *)& ri, (unsigned long)sizeof(ri));
 	}
     }
